@@ -53,6 +53,15 @@ parser.add_option("-r", "--runlist", dest="runlist",
 parser.add_option("-e", "--env", dest="environment",
                   help="Environment for newly created node",
                   default=None)
+parser.add_option("-H", "--hostname", dest="hostname",
+                  help="Hostname for newly created node (DNS will not be set up -- you must do this manually)",
+                  default=None)
+parser.add_option("-p", "--plugins", dest="plugins",
+                  help="Plugins to execute after chef bootstrapping but before chef run e.g, 'save_cloud,save_hosts'",
+                  default=None)
+parser.add_option("-P", "--post-plugins", dest="post-plugins",
+                  help="Plugins to execute after chef run. e.g, 'mark_node_as_provisioned'",
+                  default=None)
 
 class Runner(object):
     def _read_littlechef_config(self):
@@ -150,6 +159,12 @@ class Runner(object):
         if args.get('runlist'):
             args['runlist'] = args['runlist'].split(',')
 
+        if args.get('plugins'):
+            args['plugins'] = args['plugins'].split(',')
+
+        if args.get('post-plugins'):
+            args['post_plugins'] = args['post-plugins'].split(',')
+
         command.execute(**args)
 
 class MissingRequiredArguments(Exception):
