@@ -1,3 +1,4 @@
+from StringIO import StringIO
 import unittest
 import mock
 from littlechef_rackspace.lib import Host
@@ -6,7 +7,8 @@ from littlechef_rackspace.deploy import ChefDeployer
 class ChefDeployerTest(unittest.TestCase):
 
     def setUp(self):
-        self.host = Host(host_string="50.56.57.58")
+        self.host = Host(host_string="test.example.com",
+                         ip_address="50.56.57.58")
         self.ohai_data = {
             'cloud': {
                 'inet1_address': '1.2.3.4'
@@ -25,28 +27,20 @@ class ChefDeployerTest(unittest.TestCase):
 
     def _get_deployer(self, key_filename):
         deployer = ChefDeployer(key_filename=key_filename,)
-        deployer._get_ohai_attrs = mock.Mock(return_value=self.ohai_data)
         deployer._create_bootstrap_ssh_config = mock.Mock()
+
         return deployer
 
     @mock.patch('littlechef_rackspace.deploy.lc')
     @mock.patch('littlechef_rackspace.deploy.littlechef')
-    def test_deploy_sets_fabric_env(self, littlechef, lc):
-        deployer = self._get_deployer(key_filename="~/.ssh/id_rsa")
-        deployer.deploy(self.host)
-
-        self.assertEquals(self.host.host_string, lc.env.host)
-        self.assertEquals(self.host.host_string, lc.env.host_string)
-
-    @mock.patch('littlechef_rackspace.deploy.lc')
-    @mock.patch('littlechef_rackspace.deploy.littlechef')
-    def test_deploy_sets_fabric_user_and_key_filename(self, littlechef, lc):
+    def test_deploy_sets_fabric_settings(self, littlechef, lc):
         key_filename = "~/.ssh/bootstrap_rsa"
         deployer = self._get_deployer(key_filename=key_filename)
         deployer.deploy(self.host)
 
         self.assertEquals("root", lc.env.user)
-        self.assertEquals(key_filename, lc.env.key_filename)
+        self.assertEquals(self.host.get_host_string(), lc.env.host_string)
+        self.assertEquals(self.host.get_host_string(), lc.env.host)
 
     @mock.patch('littlechef_rackspace.deploy.lc')
     @mock.patch('littlechef_rackspace.deploy.littlechef')
@@ -69,9 +63,23 @@ class ChefDeployerTest(unittest.TestCase):
 
         deployer.deploy(self.host)
 
+        littlechef.lib.get_node.assert_any_call(self.host.host_string)
         node_data.update(self.ohai_data)
         littlechef.chef.save_config.assert_any_call(node_data, force=True)
 
+    @mock.patch('littlechef_rackspace.deploy.lc')
+    @mock.patch('littlechef_rackspace.deploy.littlechef')
+    def test_deploy_without_hostname_gets_node_with_ip_address(self, littlechef, lc):
+        deployer = self._get_deployer(key_filename="~/.ssh/id_rsa")
+
+        node_data = {}
+        self.host.host_string = None
+        littlechef.lib.get_node.return_value = node_data
+
+        deployer.deploy(self.host)
+
+        littlechef.lib.get_node.assert_any_call(self.host.ip_address)
+
     @mock.patch('littlechef_rackspace.deploy.lc')
     @mock.patch('littlechef_rackspace.deploy.littlechef')
     def test_deploy_with_runlist_sets_node_runlist(self, littlechef, lc):
@@ -110,7 +118,17 @@ class ChefDeployerTest(unittest.TestCase):
 
         deployer.deploy(self.host)
 
-        deployer._create_bootstrap_ssh_config.assert_any_call("./.bootstrap-config")
+        expected_ssh_config = """User root
+IdentityFile ~/.ssh/id_rsa
+StrictHostKeyChecking no
+Host test.example.com
+HostName 50.56.57.58
+"""
+
+        deployer._create_bootstrap_ssh_config.assert_any_call(
+            "./.bootstrap-config_{0}".format(self.host.get_host_string()),
+            expected_ssh_config
+        )
 
     @mock.patch('littlechef_rackspace.deploy.lc')
     @mock.patch('littlechef_rackspace.deploy.littlechef')
@@ -120,7 +138,8 @@ class ChefDeployerTest(unittest.TestCase):
         deployer.deploy(self.host)
 
         self.assertTrue(lc.env.use_ssh_config)
-        self.assertEquals(lc.env.ssh_config_path, "./.bootstrap-config")
+        self.assertEquals(lc.env.ssh_config_path,
+                          "./.bootstrap-config_{0}".format(self.host.get_host_string()))
 
     @mock.patch('littlechef_rackspace.deploy.lc')
     @mock.patch('littlechef_rackspace.deploy.littlechef')
@@ -129,4 +148,50 @@ class ChefDeployerTest(unittest.TestCase):
 
         deployer.deploy(self.host)
 
-        lc.node.assert_any_call(self.host.host_string)
\ No newline at end of file
+        lc.node.assert_any_call(self.host.host_string)
+
+    @mock.patch('littlechef_rackspace.deploy.lc')
+    @mock.patch('littlechef_rackspace.deploy.littlechef')
+    def test_deploy_with_plugins_executes_plugins_on_node(self, littlechef, lc):
+        deployer = self._get_deployer(key_filename="~/.ssh/id_rsa")
+
+        plugin = mock.Mock()
+        littlechef.lib.import_plugin.return_value = plugin
+        node_data = {'predefined': [ 'values' ]}
+        littlechef.lib.get_node.return_value = node_data
+
+        deployer.deploy(self.host, plugins=['awesome_plugin'])
+
+        littlechef.lib.import_plugin.assert_any_call('awesome_plugin')
+        plugin.execute.assert_any_call(node_data)
+
+    @mock.patch('littlechef_rackspace.deploy.lc')
+    @mock.patch('littlechef_rackspace.deploy.littlechef')
+    def test_deploy_with_plugin_prints_header(self, littlechef, lc):
+        deployer = self._get_deployer(key_filename="~/.ssh/id_rsa")
+
+        deployer.deploy(self.host, plugins=['plugin1'])
+
+        littlechef.lib.print_header.assert_any_call(
+            "Executing plugin '{0}' on {1}".format('plugin1', self.host.get_host_string())
+        )
+
+    @mock.patch('littlechef_rackspace.deploy.lc')
+    @mock.patch('littlechef_rackspace.deploy.littlechef')
+    def test_deploy_with_multiple_plugins(self, littlechef, lc):
+        deployer = self._get_deployer(key_filename="~/.ssh/id_rsa")
+
+        deployer.deploy(self.host, plugins=['plugin1', 'plugin2', 'plugin3'])
+
+        littlechef.lib.import_plugin.assert_any_call('plugin1')
+        littlechef.lib.import_plugin.assert_any_call('plugin2')
+        littlechef.lib.import_plugin.assert_any_call('plugin3')
+
+    @mock.patch('littlechef_rackspace.deploy.lc')
+    @mock.patch('littlechef_rackspace.deploy.littlechef')
+    def test_deploy_with_post_plugins(self, littlechef, lc):
+        deployer = self._get_deployer(key_filename="~/.ssh/id_rsa")
+
+        deployer.deploy(self.host, post_plugins=['postplugin'])
+
+        littlechef.lib.import_plugin.assert_any_call('postplugin')
\ No newline at end of file
